@@ -22,9 +22,14 @@
 #include <gtk/gtk.h>
 
 
-extern	void dialog_ok (char *title, char *fmt, ...);
-extern	int  dialog_yesno (char *title, int defbutton, char *fmt, ...);
-extern	char *enter_string_dialog (char *fmt, ...);
+extern	GtkWidget *dialog_create_modal_transient_window (
+                             char *title, int close_on_esc, int allow_resize);
 
+extern	void dialog_ok (char *title, char *fmt, ...);
+extern	int dialog_yesno (char *title, int defbutton, char *yes, char *no, 
+                                                              char *fmt, ...);
+extern	char *enter_string_dialog (char *fmt, ...);
+extern	char *enter_string_with_option_dialog (
+                                   char *optstr, int *optval, char *fmt, ...);
 
 #endif /* __DIALOGS_H__ */
