@@ -27,17 +27,18 @@ typedef int (*filterfunc) (struct server *);
 
 struct filter {
   char	*name;
-  struct server	**servers;
-  int	num;
+  GSList *servers;
+  int	built;
   filterfunc func;
   GtkWidget *widget;
 };
 
 
 extern	void build_filtered_list (struct filter *f, struct master *m);
+extern	int filter_add_server (struct filter *f, struct server *s);
+
 extern	void free_filter_data (struct filter *f);
 extern	void free_filters_data (void);
-extern	void init_filters (void);
 
 extern  struct filter filters[];
 extern 	struct filter *cur_filter;
