@@ -22,10 +22,13 @@
 #include "xqf.h"
 
 
+#define PSEARCH_HISTORY_MAXITEMS	16
+
 enum psearch_res { PSEARCH_CANCEL = 0, PSEARCH_OK = 1, PSEARCH_USELAST = 2 };
 
 extern	int test_player (struct player *p);
 extern	enum psearch_res psearch_dialog (void);
+extern	void psearch_free_data (void);
 
 
 #endif /* __PSEARCH_H__ */
