@@ -19,6 +19,8 @@
 #ifndef __QRUN_H__
 #define __QRUN_H__
 
+#include "xqf.h"
+
 
 struct condef {
   struct server *s;
@@ -26,18 +28,20 @@ struct condef {
   char *gamedir;
   char *observe;
   char *password;
+  char *rcon_password;
+  char *custom_cfg;
+  char *demo;
 };
 
+extern	void client_init (void);
+extern	void client_detach_all (void);
 
 extern	int quake_config_is_valid (enum server_type type);
-extern 	void launch_quake      (struct condef *con);
-extern	void launch_quake_fork (struct condef *con);
+extern 	void launch_quake (const struct condef *con, int forkit);
 
 extern	struct condef *condef_new (struct server *s);
 extern	void condef_free (struct condef *con);
 
-extern 	void set_sigchild (void);
-
 
 #endif /* __QRUN_H__ */
 
