@@ -21,16 +21,16 @@
 
 #include <gtk/gtk.h>
 
+#include "xqf.h"
 
-extern	struct server *server_lookup (char *address, int port);
-extern	struct server *server_new (char *address, int port, enum server_type type);
+
+extern	struct server *server_add (struct host *h, int port, 
+                                                       enum server_type type);
 extern	void server_unref (struct server *s);
-extern	int check_global_list (void);
+extern	int servers_total (void);
 extern	GSList *all_servers (void);
-#if 0
-extern	char *server_port (char *address, unsigned port);
-#endif
 extern	int parse_address (char *str, char **addr, int *port);
+extern	void free_servers (GSList *list);
 
 
 #endif /* __SERVER_H__ */
