@@ -23,10 +23,13 @@
 
 
 extern	GSList *qw_masters;
+extern	GSList *q2_masters;
 extern  struct master *unbound_qw;
-extern	struct master *quake2;
-extern	struct master *favorites;
+extern	struct master *unbound_q2;
+extern	struct master *qw_sources;
+extern	struct master *q2_sources;
 extern	struct master *allsources;
+extern	struct master *favorites;
 
 
 extern	void save_server_list (struct master *m);
@@ -37,6 +40,12 @@ extern	void free_masters (void);
 extern	void add_server_to_master (struct master *m, struct server *s);
 extern	void remove_server_from_master (struct master *m, struct server *s);
 
+extern	GSList *collate_server_lists (GSList *servers, GSList *sources,
+                                                      enum server_type type);
+extern	GSList *server_sources (struct server *s);
+
+extern	char *game_type_str (enum server_type st);
+
 
 #endif /* __SOURCE_H__ */
 
